/*
 * @Description: 产品标签模板相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-07-27 13:20:29
 */

import { CustModalParams } from '/@/api/tigerapi/model/systemModel';
import { ActionItem, BasicColumn } from '/@/components/Table';
import { useWebSocketStore } from '/@/store/modules/websocket';
import { buildUUID } from '/@/utils/uuid';

function _default() {
  const ActionColumn: BasicColumn = {
    width: 120,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right',
  };

  /**
   * @description: 些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (fnName: string) => {
      return {
        action: 'go', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
        url: 'BAS_LABEL_VAR/High',
        params: {
          CODE: '0',
          ID: buildUUID(),
          Name: 'BAS_LABEL_VAR', //实体名
          Title: '新增模板', //标题
          pCode: 'LABEL_CODE', //主信息关键字段CODE
          IsID: false, //是否带过去侧边框的是ID，false就是CODE，true是ID
          drawers: [
            { name: 'BAS_LABEL_VAR', code: 'LABEL_ID', type: 'one', keyName: 'BAS_LABEL_VAR', order: 'VAR_NAME' },
            // {
            //   name: 'MES_SHIFT_PRD',
            //   code: 'SFT_CODE',
            //   type: 'all',
            //   keyName: 'MES_SHIFT',
            //   order: 'SFT_CODE, SEQ',
            // },
          ], //drawers是右边弹出增改侧框的名字列表
        },
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      data.map((x) => {
        if (x.name == 'Edit') {
          x.onClick = goDetail.bind(null, args[5], params);
          x.tooltip = '模板变量';
        }
      });
      return data;
    },
    GetUseForm: () => {
      return {};
    },
    /**
     * @description: 自定义方法
     * @param {string} type
     * @param {array} args
     * @return {*}
     */
    CustFunc: (param: CustModalParams) => {
      const webSocketStore = useWebSocketStore();
      if (webSocketStore.GetSocketState == 1) {
        webSocketStore.sendMessage(
          `wsSubStrings ${param.values['ID']}_#_${param.values['TEMP_PATH']}`
        );
      }
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  /**
   * @description: 跳转到详情页面方法
   * @param {Fn} go
   * @return {*}
   */
  function goDetail(go: Fn, params: Recordable) {
    // const id = {
    //   ID: params['record'].ID,
    //   CODE: params['record']['LABEL_CODE'],
    //   Name: 'BAS_LABEL_VAR',
    //   firstTabName: '标签模板变量',
    //   secondTabName: '', //'标签过程变量',
    //   firstTitle: '模板变量',
    //   secondTitle: '', //'过程变量',
    //   pageTitle: '标签模板变量', //详情页面标题
    //   contentStr: '这里是标签模板变量管理页面，可以管理标签的模板变量或者打印过程中的变量',
    //   detailName: `模板[${params['record'].LABEL_NAME}]`,
    //   keyFieldValues: { LABEL_ID: params['record'].ID },
    //   colSlots: ['BAS_LABEL_PV1add'],
    //   SessionName: 'BAS_LABEL_VAR_update',
    // };
    const id = {
      CODE: params['record']['LABEL_CODE'],
      ID: params['record']['ID'],
      Name: 'BAS_LABEL_VAR',
      SessionName: 'BAS_LABEL_VAR_update',
      Title: `编辑模板${params['record']['LABEL_CODE']}的变量`,
      pCode: 'LABEL_CODE',
      IsID: true,
      drawers: [
        { name: 'BAS_LABEL_VAR', code: 'LABEL_ID', type: 'one', keyName: 'BAS_LABEL_VAR', order: 'VAR_NAME' },
        // {
        //   name: 'MES_SHIFT_PRD',
        //   code: 'SFT_CODE',
        //   type: 'all',
        //   keyName: 'MES_SHIFT',
        //   order: 'SFT_CODE, SEQ',
        // },
      ], //drawers是右边弹出增改侧框的名字列表
    };
    // 将对象转换为JSON字符串并保存到sessionStorage
    sessionStorage.removeItem(`${id.SessionName}_params`);
    sessionStorage.setItem(`${id.SessionName}_params`, encodeURI(JSON.stringify(id)));
    go(`/BAS_LABEL_VAR/High/${encodeURI(JSON.stringify({ sName: id.SessionName, Name: id.Name }))}`);
  }

  return [methods, ActionColumn];
}

export default _default;
